@@ -1,6 +1,8 @@
 package Dancer2::Plugin::FormValidator;
 
 use 5.24.0;
+use strict;
+use warnings;
 
 use Dancer2::Plugin;
 use Module::Load qw(autoload);
@@ -9,7 +11,7 @@ use Dancer2::Plugin::FormValidator::Validator;
 use Dancer2::Plugin::FormValidator::Config;
 use Types::Standard qw(InstanceOf HashRef ArrayRef);
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 # Global var for saving last success validation valid input.
 my $valid_input;
@@ -21,7 +23,7 @@ has config_validator => (
     isa      => InstanceOf['Dancer2::Plugin::FormValidator::Config'],
     builder  => sub {
         return Dancer2::Plugin::FormValidator::Config->new(
-            config => shift->config,
+            config => $_[0]->config,
         );
     }
 );
@@ -30,7 +32,7 @@ has config_extensions => (
     is       => 'ro',
     isa      => HashRef,
     default  => sub {
-        return shift->config->{extensions} // {},
+        return $_[0]->config->{extensions} // {},
     }
 );
 
@@ -38,7 +40,7 @@ has extensions => (
     is       => 'ro',
     isa      => ArrayRef,
     builder  => sub {
-        my $self = shift;
+        my ($self) = @_;
 
         my @extensions = map {
             my $extension = $self->config_extensions->{$_}->{provider};
@@ -58,12 +60,12 @@ has plugin_deferred => (
     is       => 'ro',
     isa      => InstanceOf['Dancer2::Plugin::Deferred'],
     builder  => sub {
-        return shift->app->with_plugin('Dancer2::Plugin::Deferred');
+        return $_[0]->app->with_plugin('Dancer2::Plugin::Deferred');
     }
 );
 
 sub BUILD {
-    shift->_register_hooks;
+    $_[0]->_register_hooks;
     return;
 }
 
@@ -74,9 +76,9 @@ sub validate {
     undef $valid_input;
 
     # Now works with arguments.
-    my $profile = %args{profile};
-    my $input   = %args{input} // $self->dsl->body_parameters->as_hashref_mixed;
-    my $lang    = %args{lang};
+    my $profile = $args{profile};
+    my $input   = $args{input} // $self->dsl->body_parameters->as_hashref_mixed;
+    my $lang    = $args{lang};
 
     if (defined $lang) {
         $self->_validator_language($lang);
@@ -116,19 +118,21 @@ sub validated {
 }
 
 sub errors {
-    return shift->_get_deferred->{messages};
+    return $_[0]->_get_deferred->{messages};
 }
 
+# Register Dancer2 hook to add custom template tokens: errors, old.
 sub _register_hooks {
-    my $self = shift;
+    my ($self) = @_;
 
     $self->app->add_hook(
         Dancer2::Core::Hook->new(
             name => 'before_template_render',
             code => sub {
-                my $tokens = shift;
-                my $errors = {};
-                my $old    = {};
+                my ($tokens) = @_;
+
+                my $errors   = {};
+                my $old      = {};
 
                 if (my $deferred = $tokens->{deferred}->{$self->config_validator->session_namespace}) {
                     $errors = delete $deferred->{messages};
@@ -146,14 +150,19 @@ sub _register_hooks {
     return;
 }
 
+# Set validator to language to $lang.
 sub _validator_language {
-    shift->config_validator->language(shift);
+    my ($self, $lang) = @_;
+
+    $self->config_validator->language($lang);
     return;
 }
 
+# Returned deferred message from session storage.
 sub _get_deferred {
-    my $self = shift;
-    return $self->plugin_deferred->deferred($self->config_validator->session_namespace);
+    return $_[0]->plugin_deferred->deferred(
+        $_[0]->config_validator->session_namespace
+    );
 }
 
 1;
@@ -171,7 +180,7 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 0.81
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -191,7 +200,7 @@ version 0.81
 
         sub profile {
             return {
-                username     => [ qw(required alpha_num_ascii length_min:4 length_max:32) ],
+                username     => [ qw(required alpha_num length_min:4 length_max:32) ],
                 email        => [ qw(required email length_max:127) ],
                 password     => [ qw(required length_max:40) ],
                 password_cnf => [ qw(required same:password) ],
@@ -227,32 +236,7 @@ The html result could be like:
 
 This is alpha version, not stable.
 
-Interfaces may change in future:
-
-=over 4
-
-=item *
-Roles: Dancer2::Plugin::FormValidator::Role::Extension, Dancer2::Plugin::FormValidator::Role::Validator.
-
-=item *
-Validators.
-
-=back
-
-Won't change:
-
-=over 4
-
-=item *
-Dsl keywords.
-
-=item *
-Template tokens.
-
-=item *
-Roles: Dancer2::Plugin::FormValidator::Role::Profile, Dancer2::Plugin::FormValidator::Role::HasMessages, Dancer2::Plugin::FormValidator::Role::ProfileHasMessages.
-
-=back
+Interfaces may change in future.
 
 If you like it - add it to your bookmarks. I intend to complete the development by the summer 2022.
 
@@ -262,10 +246,12 @@ Help is always welcome!
 =head1 DESCRIPTION
 
 This is micro-framework that provides validation in your Dancer2 application.
-It consists of dsl's keywords: validate, validator_language, errors.
+It consists of dsl's keywords: validate, validated, errors.
 It has a set of built-in validators that can be extended by compatible modules (extensions).
 Also proved runtime switching between languages, so you can show proper error messages to users.
 
+This module has a minimal set of dependencies and does not require the mandatory use of DBIc or Moose.
+
 Uses simple and declarative approach to validate forms.
 
 =head2 Validator
@@ -742,6 +728,44 @@ L<Dancer2::Plugin::FormValidator::Extension::DBIC|https://metacpan.org/pod/Dance
 
 =back
 
+=head1 HINTS
+
+If you don't want to create separated classes for your validation logic,
+you could create one base class and reuse it in your project.
+
+    ### Validator class
+
+    package Validator {
+        use Moo;
+
+        with 'Dancer2::Plugin::FormValidator::Role::Profile';
+
+        has profile_hash => (
+            is       => 'ro',
+            required => 1,
+        );
+
+        sub profile {
+            return $_[0]->profile_hash;
+        }
+    }
+
+    ### Application
+
+    use Dancer2
+
+    my $validator = Validator->new(profile_hash =>
+        {
+            email => [qw(required email)],
+        }
+    );
+
+    post '/subscribe' => sub {
+        if (not validate profile => $validator) {
+            to_json errors;
+        }
+    };
+
 =head1 TODO
 
 =over 4
