@@ -1,5 +1,8 @@
 package Dancer2::Plugin::FormValidator::Validator::Required;
 
+use strict;
+use warnings;
+
 use Moo;
 use utf8;
 use namespace::clean;
@@ -20,6 +23,7 @@ around 'stop_on_fail' => sub {
 
 sub validate {
     my ($self, $field, $input) = @_;
+
     return $self->_field_defined_and_non_empty($field, $input);
 }
 
